@@ -124,6 +124,22 @@ TSPRegistryMapping = {
     "260": "TSK.CommandAssetChunkArchive",
     "261": "TSK.AssetUploadStatusCommandArchive",
     "262": "TSK.AssetUnmaterializedOnServerCommandArchive",
+    "263": "TSK.CommandBehaviorArchive",
+    "264": "TSK.CommandBehaviorSelectionPathStorageArchive",
+    "265": "TSK.CommandActivityBehaviorArchive",
+    "273": "TSK.ActivityOnlyCommandArchive",
+    "275": "TSK.SetActivityAuthorShareParticipantIDCommandArchive",
+    "279": "TSK.ActivityAuthorCacheArchive",
+    "280": "TSK.ActivityStreamArchive",
+    "281": "TSK.ActivityArchive",
+    "282": "TSK.ActivityCommitCommandArchive",
+    "283": "TSK.ActivityStreamActivityArray",
+    "284": "TSK.ActivityStreamActivityArraySegment",
+    "285": "TSK.ActivityStreamRemovedAuthorAuditorPendingStateArchive",
+    "286": "TSK.ActivityAuthorArchive",
+    "287": "TSKSOS.ResetActivityStreamCommandArchive",
+    "288": "TSKSOS.RemoveAuthorIdentifiersCommandArchive",
+    "289": "TSK.ActivityCursorCollectionPersistenceWrapperArchive",
     "400": "TSS.StyleArchive",
     "401": "TSS.StylesheetArchive",
     "402": "TSS.ThemeArchive",
@@ -166,6 +182,8 @@ TSPRegistryMapping = {
     "635": "TSA.TitlePlacementCommandArchive",
     "636": "TSA.GalleryInfoInsertItemsCommandArchive",
     "637": "TSA.GalleryInfoRemoveItemsCommandArchive",
+    "638": "TSASOS.VerifyActivityStreamWithServerCommandArchive",
+    "639": "TSASOS.InducedVerifyActivityStreamWithServerCommandArchive",
     "2001": "TSWP.StorageArchive",
     "2002": "TSWP.SelectionArchive",
     "2003": "TSWP.DrawableAttachmentArchive",
@@ -630,6 +648,7 @@ TSPRegistryMapping = {
     "12056": "TN.FormBuilderSelectionTransformerArchive",
     "12057": "TN.FormViewerSelectionTransformerArchive",
     "12058": "TN.FormSheetSelectionTransformerArchive",
+    "12059": "TN.FormCommandActivityBehaviorArchive",
 
 }
 
